@@ -148,7 +148,14 @@ where
     );
 
     // ES2017
-    let pass = add!(pass, AsyncToGenerator, es2017::async_to_generator());
+    let pass = add!(
+        pass,
+        AsyncToGenerator,
+        es2017::async_to_generator(es2017::async_to_generator::Config {
+            ignore_function_name: loose || assumptions.ignore_function_name,
+            ignore_function_length: loose || assumptions.ignore_function_length,
+        })
+    );
 
     // ES2016
     let pass = add!(pass, ExponentiationOperator, es2016::exponentation());
